@@ -18,7 +18,7 @@ pub struct TimelineSemaphoreHandle(pub(crate) vk::Semaphore);
 /// A binary semaphore.
 #[derive(Debug, Clone)]
 pub struct BinarySemaphore {
-    pub(crate) raw: vk::Semaphore,
+    raw: vk::Semaphore,
     context: Arc<Context>,
 }
 
@@ -43,6 +43,12 @@ impl BinarySemaphore {
     pub fn handle(&self) -> BinarySemaphoreHandle {
         BinarySemaphoreHandle(self.raw)
     }
+
+    /// The raw Vulkan semaphore handle.
+    #[inline]
+    pub fn raw(&self) -> vk::Semaphore {
+        self.raw
+    }
 }
 
 /// A semaphore that uses the timeline feature.
